@@ -4,11 +4,13 @@ from __future__ import absolute_import
 
 # import apis into api package
 from symbl_rest.api.action_items_api import ActionItemsApi
+from symbl_rest.api.analytics_api import AnalyticsApi
 from symbl_rest.api.async_api import AsyncApi
 from symbl_rest.api.authentication_api import AuthenticationApi
 from symbl_rest.api.connection_to_endpoint_api import ConnectionToEndpointApi
 from symbl_rest.api.conversation_data_api import ConversationDataApi
 from symbl_rest.api.conversations_api import ConversationsApi
+from symbl_rest.api.entities_api import EntitiesApi
 from symbl_rest.api.external_event_web_hook_api import ExternalEventWebHookApi
 from symbl_rest.api.follow_ups_api import FollowUpsApi
 from symbl_rest.api.insights_api import InsightsApi
@@ -20,3 +22,4 @@ from symbl_rest.api.metric_api import MetricApi
 from symbl_rest.api.metric_entry_api import MetricEntryApi
 from symbl_rest.api.questions_api import QuestionsApi
 from symbl_rest.api.topics_api import TopicsApi
+from symbl_rest.api.trackers_api import TrackersApi
